!file: kees_simple_ice_model.f90
subroutine simple_ice_model(grid, dt, t_steps, n_t_num, dx, & ! numerics: ! spatial grid size, time step, total number of time steps, time steps between outputs, spatial discretisation step
   rho, g_grav, A_rate, n_glen, & ! physical constants
   xx, mass_b, bed, & ! input on grid: the grid, mass balance, bed elevation
   thick, & !IC on grid: initial ice thickness
   thickr, thickl, & ! BC: thickness at left and right
   thick_out) ! output: the thickness at the specified time steps
  use simple_ice_model_modules
  implicit none

  ! local variables
  real(8), parameter    :: pi = 3.1415926536
  

  !! physical constants:
  real(8) :: rho, g_grav, A_rate, n_glen ! dens. of ice, ice rate factor, n

  !! BC
  real(8) :: thickr, thickl          ! thickness at left and right edge
  !! xxxxxxxxxx

  !! numerical variables
  integer :: grid                    ! Number of nodes
  real(8) :: dt                      ! time step
  integer :: n_t_num               ! time steps between outputs
  integer :: t_steps                            ! number of time steps
  real(8) :: dx                                    ! node spacing
  real(8), dimension(n_t_num) :: times_out         ! output times
  real(8) :: const_coef                                 ! a constant
  real(8) :: time                                 ! current model time
  
  !! unstaggered grid
  real(8), dimension(grid) :: xx         ! node positions
  real(8), dimension(grid) :: thick      ! ice thickness
  real(8), dimension(grid, (t_steps/n_t_num)) :: thick_out      ! ice thickness
  real(8), dimension(grid) :: dthick_dt  ! ice thickness time derivative
  real(8), dimension(grid) :: mass_b     ! mass balance
  real(8), dimension(grid) :: bed        ! bed elevation




  !! staggered grid
  real(8), dimension(grid-1) :: diffus     ! diffusion
  
  !! physical constants
  

  !! counters and such
  integer :: ii, jj, iii

!! f2py declarations
!f2py integer  intent(in) :: grid, t_steps
!f2py real(8)  intent(in) :: dt, t_steps
!f2py real(8)  intent(in) :: thickr, thickl, dx
!f2py real(8)  intent(in) :: rho, g_grav, A_rate, n_glen
!f2py real(8)  intent(in), copy :: xx, bed, mass_b, thick
!f2py real(8)  intent(out) :: thick_out, times_out
  
  !! setup
  const_coef = 2*A_rate/(n_glen+2)*(rho*g_grav)**n_glen

  iii = 1
  time = 0

  do ii=1,t_steps
     ! do output at specified 
     if (mod(ii-1, n_t_num)==0) then
        thick_out(:,iii) = thick
        times_out(iii) = time
        iii = iii+ 1
     end if
     ! increase time (only needed for output)
     time = time+ dt
     ! compute the diffusivity: difus
     diffus = calc_diffus(thick, bed, dx, const_coef, n_glen)
     ! assemble dthick_dt
     dthick_dt = pad(diff_1( &
                  diffus*diff_1((thick+bed), dx), dx), thickl, thickr) &
                  + mass_b
     ! time step
     thick = time_step(thick, dthick_dt, dt)
     ! BC
     thick(1) = thickl
     thick(grid) = thickr
     do jj=1,grid ! set H to zero if H<0
        if (thick(jj)<0.) then
          thick(jj) = 0.
        end if
     end do
  end do
!   print *, 'sadf', grid, (t_steps/n_t_num+1)
end subroutine simple_ice_model
