"""
This is a place for small helper functions to live.
"""

import os
import Scientific.IO.NetCDF

def CDL2nc(input_file, output_file=None):
    """
    Makes a netCDF file from a text file in the CDL format.

    @type input_file: string
    @param input_file: The name of the input file.

    @type output_file: string

    @param output_file: The name of the output file, if none is given
                        the same name as the CDL file is used with a
                        C{.nc} extension.
    """
    if output_file is None:
        output_file = os.path.splitext(input_file)[0] + '.nc'
    # run the command ncgen
    os.system('ncgen -o ' + output_file + ' ' + input_file)

def nc2CDL(input_file, output_file=None):
    """
    Performs a C{ncdump}.

    @type input_file: string
    @param input_file: The name of the input file.

    @type output_file: string

    @param output_file: The name of the output file, if none is given
                        the same name as the netCDF file is used with a
                        C{.CDL} extension.
    """
    if output_file is None:
        output_file = os.path.splitext(input_file)[0] + '.CDL'
    # run ncdump
    os.system('ncdump ' + input_file + ' > ' + output_file)


def open_netCDF_into_python(input_file, rw_opt='r'):
    """
    This opens a netCDF file.

    @type input_file: string
    @param input_file: The netCDF file to be read.

    @type rw_opt: stirng
    @param rw_opt: Reading 'r' (default), writing 'w'

    @return: A C{Scientific.IO.NetCDF.NetCDFFile} instance
    """
    if type(input_file)!=type(''):
        input_file = str(input_file)
    return Scientific.IO.NetCDF.NetCDFFile(input_file, rw_opt)

if __name__=='__main__':
    pass

