import numpy as N
import pylab as P

import simple_ice_model_even_more

# import os
# import sys
# sys.path.append('..')
# from py_fortran_tools import *

def run():
    # physical params
    rho=920.
    g_grav=9.8
    A_rate=1.e-16
    n_glen=3.
    
    # numerical params
    grid = 51
    dt = 0.1
    t_start = 0.
    t_final = 1000.
    times_out_delta_t = 10 # how often output is made
    t_steps = N.round((t_final-t_start)/dt)
    
    xl = 0
    xr =50e3
    mass_b_0=4.
    mass_b_1=0.2e-3
    dbed_dx=0.025

    # the time steps
    tt = N.arange(t_start, t_final+dt, dt)
    # the indices of the output times
    t_output_ind = N.where(N.mod(tt,times_out_delta_t)==0)
    # the output times
    t_out = tt[t_output_ind]
    ## input on the grid
    # make the spatial discretisation
    xx = N.linspace(xl, xr, grid)
    # make a bed 
    bed = -dbed_dx * xx
    # mass-balance vector
    mass_b =     mass_b_0 - mass_b_1*xx
    # initial ice sheet elevation
    thick_IC = xx*0

    # run the model with above IC and parameters
    thick = simple_ice_model_even_more.simple_ice_model(
        grid, dt, t_steps, t_out_ind, dx, #numerics
        rho, g_grav, A_rate, n_glen, # physical constants
        xx, mass_b, bed, # input on grid
        thick, # IC
        thickr, thickl) #BC

    P.figure()
    P.plot(xx/1e3, bed+thick[:,-1], 'b')
    P.hold(True)
    P.plot(xx/1e3, bed, 'r')
    P.xlabel('x (km)')
    P.ylabel('b+H (m)')

if __name__=='__main__':
    run()
    P.show()
