!file: simple_ice_model.f90
subroutine simple_ice_model(grid, dt, t_steps, t_out_ind, dx, & ! numerics
   rho, g_grav, A_rate, n_glen, & ! physical constants
   xx, mass_b, bed, & ! input on grid
   thick, & !IC
   thickr, thickl, & ! BC
   thick_out) ! output
  use simple_ice_model_modules
  implicit none

  ! local variables
  real(8), parameter    :: pi = 3.1415926536
  

  !! physical constants:
  real(8) :: rho, g_grav, A_rate, n_glen ! dens. of ice, ice rate factor, n

  !! BC
  real(8) :: thickr, thickl          ! thickness at left and right edge
  !! xxxxxxxxxx

  !! numerical variables
  integer :: grid                    ! Number of nodes
  real(8) :: dt                      ! time step
  integer :: t_out_ind               ! index of output time
  integer :: t_steps                            ! number of time steps
  real(8) :: dx                                    ! node spacing
  real(8), dimension(n_t_out) :: times_out         ! output times
  real(8) :: const_coef                                 ! a constant
  real(8) :: time                                 ! current model time
  
  !! unstaggered grid
  real(8), dimension(grid) :: xx         ! node positions
  real(8), dimension(grid) :: thick      ! ice thickness
  real(8), dimension(grid, n_t_out+1) :: thick_out      ! ice thickness
  real(8), dimension(grid) :: dthick_dt  ! ice thickness time derivative
  real(8), dimension(grid) :: mass_b     ! mass balance
  real(8), dimension(grid) :: bed        ! bed elevation

  !! staggered grid
  real(8), dimension(grid-1) :: diffus     ! diffusion
  
  !! physical constants
  

  !! counters and such
  integer :: ii, jj, iii

!! f2py declarations
subroutine simple_ice_model(grid, dt, t_steps, t_out_ind, dx, & ! numerics
   rho, g_grav, A_rate, n_glen, & ! physical constants
   xx, mass_b, bed, & ! input on grid
   thick, & !IC
   thickr, thickl, & ! BC
   thick_out) ! output


!f2py integer optional, intent(in) :: grid, t_steps, t_out_ind
!f2py real(8) optional, intent(in) :: dt, t_steps
!f2py real(8) optional, intent(in) :: thickr, thickl, dx
!f2py real(8) optional, intent(in) :: rho=920., g_grav=9.8, A_rate=1.e-16, n_glen=3.
!f2py real(8) intent(in) :: xx, bed, mass_b, thick
!f2py real(8) optional, intent(out) :: thick_out, times_out
  
  !! setup
  t_out_ind = t_out_ind+1 ! Python runs index from zero!!!

  const_coef = 2*A_rate/(n_glen+2)*(rho*g_grav)**n_glen

  iii = 1
  time = 0
  do ii=1,t_steps
     ! do output at specified 
     if (ii==t_output_ind) then
        thick_out(:,iii) = thick
        times_out(iii) = time
        iii = iii+ 1
     end if
     ! increase time (only needed for output)
     time = time+ dt
     
     ! compute the diffusivity: difus
     diffus = calc_diffus(thick, bed, dx, const_coef, n_glen)
     ! assemble dthick_dt
     dthick_dt = pad(diff_1( &
                  diffus*diff_1((thick+bed), dx), dx), thickl, thickr) &
                  + mass_b
     ! time step
     thick = time_step(thick, dthick_dt, dt)
     ! BC: are included when doing the pad function

     do jj=1,grid ! set H to zero if H<0
        if (thick(jj)<0.) then
          thick(jj) = 0.
        end if
     end do
  end do
 
end subroutine simple_ice_model
